import{b as s}from"./index.94ff652e.js";import{c as t}from"./vue-i18n.runtime.be94b133.js";var o={failed:"Action failed",success:"Action was successful",title:"GreaterWMS Open Source Warehouse Management System",description:"GreaterWMS Open Source Warehouse Management System",keywords:"greaterwms, \u805A\u5546\u6C47wms,wms-system,open source wms system,\u5F00\u6E90wms,\u5F00\u6E90\u4ED3\u5E93\u7BA1\u7406\u8F6F\u4EF6,warehouse management system, free wms",gohome:"Go Home",cancel:"Cancel",submit:"Submit",login:"Login",register:"Register",passworderror:"Password Is Not The Same",logout:"Logout",logoutnotice:"Welcome Back Again",username:"User Name",password:"Enter Password",password1:"Enter Password",password2:"Enter Password Again",usererror:"User Name Or Password Cannot Be Empty",menuTab:{home:"Home",test1:"Tab Test-1",test2:"Tab Test-1"},menuLink:{test1:"Link Test-1",test2:"Link Test-2"},400:"Bad request (400)",401:"Authorization not obtained (401)",403:"Access denied (403)",404:"Resource does not exist (404)",405:"The function is disabled (405)",408:"Request timed out (408)",409:"Data conflict (409)",410:"Data has been deleted (410)",500:"Server error (500)",501:"Service not implemented (501)",502:"Network error (502)",503:"Service unavailable (503)",504:"Network timeout (504)",505:"HTTP version is not supported (505)"},r={failed:"\u5931\u8D25",success:"\u6210\u529F",title:"Bomiot",description:"GreaterWMS\u5F00\u6E90\u4ED3\u5E93\u7BA1\u7406\u7CFB\u7EDF",keywords:"greaterwms, \u805A\u5546\u6C47wms,wms-system,open source wms system,\u5F00\u6E90wms,\u5F00\u6E90\u4ED3\u5E93\u7BA1\u7406\u8F6F\u4EF6,warehouse management system, free wms",gohome:"\u56DE\u5230\u9996\u9875",cancel:"\u53D6\u6D88",submit:"\u63D0\u4EA4",login:"\u767B\u5165",register:"\u6CE8\u518C",passworderror:"\u4E24\u6B21\u8F93\u5165\u7684\u5BC6\u7801\u4E0D\u4E00\u6837",logout:"\u9000\u51FA",logoutnotice:"\u6B22\u8FCE\u518D\u6765",username:"\u7528\u6237\u540D",password:"\u8F93\u5165\u5BC6\u7801",password1:"\u8F93\u5165\u5BC6\u7801",password2:"\u518D\u6B21\u8F93\u5165\u5BC6\u7801",usererror:"\u7528\u6237\u540D\u6216\u5BC6\u7801\u4E0D\u80FD\u4E3A\u7A7A",menuTab:{home:"\u9996\u9875",test1:"Tab \u6D4B\u8BD5-1",test2:"Tab \u6D4B\u8BD5-2"},menuLink:{test1:"Link \u6D4B\u8BD5-1",test2:"Link \u6D4B\u8BD5-2"},400:"\u9519\u8BEF\u8BF7\u6C42(400)",401:"\u672A\u53D6\u5F97\u6388\u6743(401)",403:"\u62D2\u7EDD\u8BBF\u95EE(403)",404:"\u8D44\u6E90\u4E0D\u5B58\u5728(404)",405:"\u8BE5\u529F\u80FD\u88AB\u7981\u7528(405)",408:"\u8BF7\u6C42\u8D85\u65F6(408)",409:"\u6570\u636E\u51B2\u7A81(409)",410:"\u6570\u636E\u5DF2\u5220\u9664(410)",500:"\u670D\u52A1\u5668\u9519\u8BEF(500)",501:"\u670D\u52A1\u672A\u5B9E\u73B0(501)",502:"\u7F51\u7EDC\u9519\u8BEF(502)",503:"\u670D\u52A1\u4E0D\u53EF\u7528(503)",504:"\u7F51\u7EDC\u8D85\u65F6(504)",505:"HTTP\u7248\u672C\u4E0D\u53D7\u652F\u6301(505)"},a={"en-US":o,"zh-CN":r};const n=t({legacy:!1,locale:"en-US",globalInjection:!0,messages:a});var u=s(({app:e})=>{e.use(n)});export{u as default,n as i18n};
