import{b as c,N as o}from"./index.94ff652e.js";const t="right",e=!0,s=!0,i=!0,r="flat",n=2e3;var l=c(async()=>{o.registerType("success",{icon:"check_circle",position:t,progress:e,multiLine:s,group:i,color:"positive",textColor:"white",classes:r,timeout:n}),o.registerType("error",{icon:"bug_report",position:t,progress:e,multiLine:s,group:i,color:"negative",textColor:"white",classes:r,timeout:n}),o.registerType("warning",{icon:"warning",position:t,progress:e,multiLine:s,group:i,color:"warning",textColor:"black",classes:r,timeout:n}),o.registerType("info",{icon:"contact_support",position:t,progress:e,multiLine:s,group:i,color:"info",textColor:"white",classes:r,timeout:n})});export{l as default};
